use strict;
use Digest::SHA3 qw(
	shake128	shake128_base64		shake128_hex
	shake256	shake256_base64		shake256_hex
	sha3_224	sha3_224_base64		sha3_224_hex
	sha3_256	sha3_256_base64		sha3_256_hex
	sha3_384	sha3_384_base64		sha3_384_hex
	sha3_512	sha3_512_base64		sha3_512_hex);

print "1..1\n";
print "ok 1\n";
